@@ -109,11 +109,15 @@ class MathJS(object):
                 # Lists are used to hold values for functions
                 parsed_tokens[i] = self.eval_parsed_tokens(v)
                 if current_fn:
-                    # Evaluate current function
-                    if isinstance(parsed_tokens[i], tuple):
-                        value = self.fn[current_fn](*parsed_tokens[i])
-                    else:
-                        value = self.fn[current_fn](parsed_tokens[i])
+                    try:
+                        # Evaluate current function
+                        if isinstance(parsed_tokens[i], tuple):
+                            value = self.fn[current_fn](*parsed_tokens[i])
+                        else:
+                            value = self.fn[current_fn](parsed_tokens[i])
+                    except ZeroDivisionError:
+                        # User can't create short-circuit to avoid divByZero (ie. ifElseAlt), so need this catch
+                        value = 0
                     current_fn = None
                 else:
                     if isinstance(parsed_tokens[i], tuple):
